=== modified file 'drizzled/Makefile.am'
--- drizzled/Makefile.am	2008-08-12 03:12:57 +0000
+++ drizzled/Makefile.am	2008-08-12 06:19:25 +0000
@@ -68,6 +68,7 @@
 		 $(top_builddir)/drizzled/serialize/libserialize.la \
 		 $(libevent_libs) \
 		 @mysql_plugin_libs@ \
+		 -lprotobuf \
 		 $(LDADD) \
 		 $(CXXLDFLAGS) \
 		 $(LIBDL_LIBS) $(LIBEVENT_LIBS)

=== modified file 'drizzled/sql_db.cc'
--- drizzled/sql_db.cc	2008-08-12 03:12:57 +0000
+++ drizzled/sql_db.cc	2008-08-12 06:19:25 +0000
@@ -15,7 +15,10 @@
 
 
 /* create and drop of databases */
+#include <string>
+#include <fstream>
 #include <drizzled/serialize/serialize.h>
+using namespace std;
 #include <drizzled/server_includes.h>
 #include <mysys/mysys_err.h>
 #include <mysys/my_dir.h>
@@ -327,11 +330,12 @@
   1	Could not create file or write to it.  Error sent through my_error()
 */
 
-static bool write_db_opt(THD *thd, const char *path, HA_CREATE_INFO *create)
+static bool write_db_opt(THD *thd, const char *path, const char *name, HA_CREATE_INFO *create)
 {
-  register File file;
-  char buf[256]; // Should be enough for one option
   bool error= true;
+  schema::Schema db;
+
+  assert(name);
 
   if (!create->default_table_charset)
     create->default_table_charset= thd->variables.collation_server;
@@ -339,20 +343,14 @@
   if (put_dbopt(path, create))
     return 1;
 
-  if ((file=my_create(path, CREATE_MODE,O_RDWR | O_TRUNC,MYF(MY_WME))) >= 0)
-  {
-    uint32_t length;
-    length= (uint32_t) (strxnmov(buf, sizeof(buf)-1, "default-character-set=",
-                              create->default_table_charset->csname,
-                              "\ndefault-collation=",
-                              create->default_table_charset->name,
-                              "\n", NullS) - buf);
-
-    /* Error is written by my_write */
-    if (!my_write(file,(uchar*) buf, length, MYF(MY_NABP+MY_WME)))
-      error= false;
-    my_close(file,MYF(0));
-  }
+  db.set_name(name);
+  db.set_characterset(create->default_table_charset->csname);
+  db.set_collation(create->default_table_charset->name);
+
+  fstream output(path, ios::out | ios::trunc | ios::binary);
+  if (!db.SerializeToOstream(&output)) 
+    error= false;
+
   return error;
 }
 
@@ -374,10 +372,9 @@
 
 bool load_db_opt(THD *thd, const char *path, HA_CREATE_INFO *create)
 {
-  File file;
-  char buf[256];
   bool error=1;
-  uint nbytes;
+  schema::Schema db;
+  string buffer;
 
   memset(create, 0, sizeof(*create));
   create->default_table_charset= thd->variables.collation_server;
@@ -386,54 +383,28 @@
   if (!get_dbopt(path, create))
     return(0);
 
-  /* Otherwise, load options from the .opt file */
-  if ((file=my_open(path, O_RDONLY | O_SHARE, MYF(0))) < 0)
-    goto err1;
-
-  IO_CACHE cache;
-  if (init_io_cache(&cache, file, IO_SIZE, READ_CACHE, 0, 0, MYF(0)))
-    goto err2;
-
-  while ((int) (nbytes= my_b_gets(&cache, (char*) buf, sizeof(buf))) > 0)
-  {
-    char *pos= buf+nbytes-1;
-    /* Remove end space and control characters */
-    while (pos > buf && !my_isgraph(&my_charset_latin1, pos[-1]))
-      pos--;
-    *pos=0;
-    if ((pos= strchr(buf, '=')))
-    {
-      if (!strncmp(buf,"default-character-set", (pos-buf)))
-      {
-        /*
-           Try character set name, and if it fails
-           try collation name, probably it's an old
-           4.1.0 db.opt file, which didn't have
-           separate default-character-set and
-           default-collation commands.
-        */
-        if (!(create->default_table_charset=
-        get_charset_by_csname(pos+1, MY_CS_PRIMARY, MYF(0))) &&
-            !(create->default_table_charset=
-              get_charset_by_name(pos+1, MYF(0))))
-        {
-          sql_print_error("Error while loading database options: '%s':",path);
-          sql_print_error(ER(ER_UNKNOWN_CHARACTER_SET),pos+1);
-          create->default_table_charset= default_charset_info;
-        }
-      }
-      else if (!strncmp(buf,"default-collation", (pos-buf)))
-      {
-        if (!(create->default_table_charset= get_charset_by_name(pos+1,
-                                                           MYF(0))))
-        {
-          sql_print_error("Error while loading database options: '%s':",path);
-          sql_print_error(ER(ER_UNKNOWN_COLLATION),pos+1);
-          create->default_table_charset= default_charset_info;
-        }
-      }
-    }
-  }
+  fstream input(path, ios::in | ios::binary);
+  if (!input)
+    goto err1;
+  else if (!db.ParseFromIstream(&input))
+    goto err1;
+
+  buffer= db.characterset();
+  if (!(create->default_table_charset= get_charset_by_csname(buffer.c_str(), MY_CS_PRIMARY, MYF(0))))
+  {
+    sql_print_error("Error while loading database options: '%s':",path);
+    sql_print_error(ER(ER_UNKNOWN_COLLATION), buffer.c_str());
+    create->default_table_charset= default_charset_info;
+  }
+
+  buffer= db.collation();
+  if (!(create->default_table_charset= get_charset_by_name(buffer.c_str(), MYF(0))))
+  {
+    sql_print_error("Error while loading database options: '%s':",path);
+    sql_print_error(ER(ER_UNKNOWN_COLLATION), buffer.c_str());
+    create->default_table_charset= default_charset_info;
+  }
+
   /*
     Put the loaded value into the hash.
     Note that another thread could've added the same
@@ -443,9 +414,6 @@
   */
   error= put_dbopt(path, create);
 
-  end_io_cache(&cache);
-err2:
-  my_close(file,MYF(0));
 err1:
   return(error);
 }
@@ -625,7 +593,7 @@
 
   path[path_len-1]= FN_LIBCHAR;
   strmake(path+path_len, MY_DB_OPT_FILE, sizeof(path)-path_len-1);
-  if (write_db_opt(thd, path, create_info))
+  if (write_db_opt(thd, path, db, create_info))
   {
     /*
       Could not create options file.
@@ -735,7 +703,7 @@
      "table name to file name" encoding.
   */
   build_table_filename(path, sizeof(path), db, "", MY_DB_OPT_FILE, 0);
-  if ((error=write_db_opt(thd, path, create_info)))
+  if ((error=write_db_opt(thd, path, db, create_info)))
     goto exit;
 
   /* Change options if current database is being altered. */

=== modified file 'mysys/my_sys.h'
--- mysys/my_sys.h	2008-08-10 22:14:13 +0000
+++ mysys/my_sys.h	2008-08-12 06:19:25 +0000
@@ -804,8 +804,7 @@
 
 extern const CHARSET_INFO *get_charset(uint cs_number, myf flags);
 extern const CHARSET_INFO *get_charset_by_name(const char *cs_name, myf flags);
-extern const CHARSET_INFO *get_charset_by_csname(const char *cs_name,
-					                             uint cs_flags, myf my_flags);
+extern const CHARSET_INFO *get_charset_by_csname(const char *cs_name, uint cs_flags, myf my_flags);
 
 extern bool resolve_charset(const char *cs_name,
                             const CHARSET_INFO *default_cs,

